searchData={"items":[{"type":"module","title":"SPARQL.Client","doc":"A SPARQL protocol client.\n\nThe [SPARQL Protocol](https://www.w3.org/TR/sparql11-protocol/) defines how the operations\nspecified in the SPARQL query and update specs can be requested by a client from a\nSPARQL service via HTTP.\n\nThis module provides dedicated functions for the various forms of SPARQL query and update\noperations and generic `query/3` and `update/3` for the query and update operations.\n\nFor a general introduction you may refer to the guides on the [homepage](https://rdf-elixir.dev).","ref":"SPARQL.Client.html"},{"type":"module","title":"Raw-mode - SPARQL.Client","doc":"The query functions can be called with a `SPARQL.Query` struct or a SPARQL query as a raw string.\nBy default, a SPARQL query string will be parsed into a `SPARQL.Query` struct for validation\npurposes before the string is sent via an HTTP request to the SPARQL protocol service endpoint.\nThis parsing step can be omitted by setting `:raw_mode` option to `true` on the dedicated\nfunctions for the various SPARQL operation forms.\n\n    \"SELECT * { ?s ?p ?o .}\"\n    |> SPARQL.Client.select(\"http://example.com/sparql\", raw_mode: true)\n\nOn the generic `SPARQL.Client.query/3` this raw-mode is not supported, since the parsing is\nneeded there to determine the query form which determines which result to expect.\n\nFor SPARQL update operations the picture is a little different. The SPARQL.ex package doesn't\nprovide parsing of SPARQL updates (yet), but except for `INSERT` and `DELETE` updates this isn't\nactually needed, since all elements of the updates can be provided directly to the respective\nfunctions for the update forms, which will generate valid SPARQL updates.\n\n    RDF.Graph.new({EX.S, EX.p, EX.O})\n    |> SPARQL.Client.insert_data(\"http://example.com/sparql\")\n\nYou can still provide handwritten update strings to these functions, but due to the lack of\nSPARQL update parsing the raw-mode is mandatory then. For the `INSERT` and `DELETE` update\nforms this the only way to request them for now.\n\n    \"\"\"\n    PREFIX dc:   \n    PREFIX xsd:  \n\n    INSERT\n    { GRAPH   { ?book ?p ?v } }\n    WHERE\n    { GRAPH   \n         { ?book dc:date ?date .\n           FILTER ( ?date > \"1970-01-01T00:00:00-02:00\"^^xsd:dateTime )\n           ?book ?p ?v\n    } }\n    \"\"\"\n    |> SPARQL.Client.insert(\"http://example.com/sparql\", raw_mode: true)","ref":"SPARQL.Client.html#module-raw-mode"},{"type":"module","title":"Specifying custom headers - SPARQL.Client","doc":"Custom headers for the HTTP request to the SPARQL service can be specified with the `headers`\noption and a map.\n\n    SPARQL.Client.query(query, \"http://some.company.org/private/sparql\",\n      headers: %{\"Authorization\" => \"Basic XXX==\"})","ref":"SPARQL.Client.html#module-specifying-custom-headers"},{"type":"module","title":"Specifying Tesla adapter specific options - SPARQL.Client","doc":"The keyword list provided under the  `request_opts` options, will be passed as the `opts` option\nvalue to the `Tesla.request/2` function.\nThis allows for example to set the timeout value for the Hackney adapter like this:\n\n```elixir\nSPARQL.Client.query(query, \"http://example.com/sparql\",\n  request_opts: [adapter: [recv_timeout: 30_000]])\n```","ref":"SPARQL.Client.html#module-specifying-tesla-adapter-specific-options"},{"type":"module","title":"Other options - SPARQL.Client","doc":"- `max_redirects`: the number of redirects to follow before the operation fails (default: `5`)\n- `logger`: allows to enable and configure the `Tesla.Middleware.Logger` by\n  either setting it `true` or providing the `Tesla.Middleware.Logger` options\n  (default: `false`)","ref":"SPARQL.Client.html#module-other-options"},{"type":"module","title":"Application configuration of default values - SPARQL.Client","doc":"Several default values for the options of the operations can be configured via the\nMix application environment.\nHere's an example configuration showing all available configuration options:\n\n    config :sparql_client,\n      protocol_version: \"1.1\",\n      query_request_method: :get,\n      update_request_method: :direct,\n      query_result_format: %{\n        select: :json,\n        ask: :json,\n        construct: :turtle,\n        describe: :turtle\n      },\n      http_headers: %{\"Authorization\" => \"Basic YWxhZGRpbjpvcGVuc2VzYW1l\"},\n      tesla_request_opts: [adapter: [recv_timeout: 30_000]],\n      max_redirects: 3,\n      raw_mode: true\n\nThe `http_headers` can also be set to a function receiving the `SPARQL.Client.Request`\nstruct and the computed default headers:\n\n    defmodule SomeModule do\n      def http_header_config(request, _headers) do\n        if request.sparql_operation_type == SPARQL.Client.Update do\n          %{\"Authorization\" => \"Basic YWxhZGRpbjpvcGVuc2VzYW1l\"}\n        else\n          %{}\n        end\n    end\n\n    config :sparql_client,\n      http_headers: &SomeModule.http_header_config/2,","ref":"SPARQL.Client.html#module-application-configuration-of-default-values"},{"type":"function","title":"SPARQL.Client.add/2","doc":"Executes a SPARQL `ADD` update operation against a service endpoint.\n\nThe source graph must be specified with the `:graph` option and the destination graph with the\n`:to` option either as a string, `RDF.IRI`, vocabulary namespace term for the graph name or\n`:default` for the default graph.\n\n    SPARQL.Client.add(\"http://example.com/sparql\",\n      from: \"http://example.com/Graph1\", to: \"http://example.com/Graph2\")\n\n    SPARQL.Client.add(\"http://example.com/sparql\",\n      from: :default, to: EX.Graph)\n\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#add/2"},{"type":"function","title":"SPARQL.Client.add/3","doc":"Executes a SPARQL `ADD` update operation against a service endpoint.\n\nThis version only allows execution of `ADD` updates given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"ADD GRAPH   TO GRAPH  \"\n    |> SPARQL.Client.add(\"http://example.com/sparql\", raw_mode: true)\n\nSee `add/2` for how to execute a `ADD` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#add/3"},{"type":"function","title":"SPARQL.Client.ask/3","doc":"Executes a SPARQL `ASK` query operation against a service endpoint.\n\nSee documentation of the generic `query/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#ask/3"},{"type":"function","title":"SPARQL.Client.clear/2","doc":"Executes a SPARQL `CLEAR` update operation against a service endpoint.\n\nThe graph name must be specified with the `:graph` option either as a string, `RDF.IRI`,\nvocabulary namespace term or one of the special values `:default`, `:named`, `:all`.\n\n    SPARQL.Client.clear(\"http://example.com/sparql\", graph: \"http://example.com/Graph\")\n\n    SPARQL.Client.clear(\"http://example.com/sparql\", graph: EX.Graph)\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#clear/2"},{"type":"function","title":"SPARQL.Client.clear/3","doc":"Executes a SPARQL `CLEAR` update operation against a service endpoint.\n\nThis version only allows execution of `CLEAR` updates given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"CLEAR  \"\n    |> SPARQL.Client.clear(\"http://example.com/sparql\", raw_mode: true)\n\nSee `clear/2` for how to execute a `CLEAR` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#clear/3"},{"type":"function","title":"SPARQL.Client.construct/3","doc":"Executes a SPARQL `CONSTRUCT` query operation against a service endpoint.\n\nSee documentation of the generic `query/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#construct/3"},{"type":"function","title":"SPARQL.Client.copy/2","doc":"Executes a SPARQL `COPY` update operation against a service endpoint.\n\nThe source graph must be specified with the `:graph` option and the destination graph with the\n`:to` option either as a string, `RDF.IRI`, vocabulary namespace term for the graph name or\n`:default` for the default graph.\n\n    SPARQL.Client.copy(\"http://example.com/sparql\",\n      from: \"http://example.com/Graph1\", to: \"http://example.com/Graph2\")\n\n    SPARQL.Client.copy(\"http://example.com/sparql\",\n      from: :default, to: EX.Graph)\n\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#copy/2"},{"type":"function","title":"SPARQL.Client.copy/3","doc":"Executes a SPARQL `COPY` update operation against a service endpoint.\n\nThis version only allows execution of `COPY` updates given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"COPY GRAPH   TO GRAPH  \"\n    |> SPARQL.Client.copy(\"http://example.com/sparql\", raw_mode: true)\n\nSee `copy/2` for how to execute a `COPY` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#copy/3"},{"type":"function","title":"SPARQL.Client.create/2","doc":"Executes a SPARQL `CREATE` update operation against a service endpoint.\n\nThe graph name must be specified with the `:graph` option either as a string, `RDF.IRI`,\nvocabulary namespace term or one of the special values `:default`, `:named`, `:all`.\n\n    SPARQL.Client.create(\"http://example.com/sparql\", graph: \"http://example.com/Graph\")\n\n    SPARQL.Client.create(\"http://example.com/sparql\", graph: EX.Graph)\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#create/2"},{"type":"function","title":"SPARQL.Client.create/3","doc":"Executes a SPARQL `CREATE` update operation against a service endpoint.\n\nThis version only allows execution of `CREATE` updates given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"CREATE  \"\n    |> SPARQL.Client.create(\"http://example.com/sparql\", raw_mode: true)\n\nSee `create/2` for how to execute a `CREATE` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#create/3"},{"type":"function","title":"SPARQL.Client.delete/3","doc":"Executes a SPARQL `DELETE` update operation against a service endpoint.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#delete/3"},{"type":"function","title":"SPARQL.Client.delete_data/3","doc":"Executes a SPARQL `DELETE DATA` update operation against a service endpoint.\n\nThe `DELETE DATA` update can either be given as string (only in raw-mode; see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode) or\nby providing the data to be deleted directly via an RDF.ex data structure\n(`RDF.Graph`, `RDF.Description` or `RDF.Dataset`).\n\n    RDF.Graph.new({EX.S, EX.p, EX.O})\n    |> SPARQL.Client.delete_data(\"http://example.com/sparql\")\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#delete_data/3"},{"type":"function","title":"SPARQL.Client.describe/3","doc":"Executes a SPARQL `DESCRIBE` query operation against a service endpoint.\n\nSee documentation of the generic `query/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#describe/3"},{"type":"function","title":"SPARQL.Client.drop/2","doc":"Executes a SPARQL `DROP` update operation against a service endpoint.\n\nThe graph name must be specified with the `:graph` option either as a string, `RDF.IRI`,\nvocabulary namespace term or one of the special values `:default`, `:named`, `:all`.\n\n    SPARQL.Client.drop(\"http://example.com/sparql\", graph: \"http://example.com/Graph\")\n\n    SPARQL.Client.drop(\"http://example.com/sparql\", graph: EX.Graph)\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#drop/2"},{"type":"function","title":"SPARQL.Client.drop/3","doc":"Executes a SPARQL `DROP` update operation against a service endpoint.\n\nThis version only allows execution of `DROP` updates given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"DROP  \"\n    |> SPARQL.Client.drop(\"http://example.com/sparql\", raw_mode: true)\n\nSee `drop/2` for how to execute a `DROP` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#drop/3"},{"type":"function","title":"SPARQL.Client.insert/3","doc":"Executes a SPARQL `INSERT` update operation against a service endpoint.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#insert/3"},{"type":"function","title":"SPARQL.Client.insert_data/3","doc":"Executes a SPARQL `INSERT DATA` update operation against a service endpoint.\n\nThe `INSERT DATA` update can either be given as string (only in raw-mode; see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode) or\nby providing the data to be inserted directly via an RDF.ex data structure\n(`RDF.Graph`, `RDF.Description` or `RDF.Dataset`).\n\n    RDF.Graph.new({EX.S, EX.p, EX.O})\n    |> SPARQL.Client.insert_data(\"http://example.com/sparql\")\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#insert_data/3"},{"type":"function","title":"SPARQL.Client.load/2","doc":"Executes a SPARQL `LOAD` update operation against a service endpoint.\n\nThe URL from to be loaded must be specified with the `:from` option. The graph name\nto which the data should be loaded can be given with the `:to` option. Both options\nexpect a URI as a value which can be given as a string, `RDF.IRI` or vocabulary namespace term.\n\n    SPARQL.Client.load(\"http://example.com/sparql\", from: \"http://example.com/Resource\")\n\n    SPARQL.Client.load(\"http://example.com/sparql\", from: EX.Resource, to: EX.Graph)\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#load/2"},{"type":"function","title":"SPARQL.Client.load/3","doc":"Executes a SPARQL `LOAD` update operation against a service endpoint.\n\nThis version only allows execution of `LOAD` update given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"LOAD  \"\n    |> SPARQL.Client.load(\"http://example.com/sparql\", raw_mode: true)\n\nSee `load/2` for how to execute a `LOAD` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#load/3"},{"type":"function","title":"SPARQL.Client.move/2","doc":"Executes a SPARQL `MOVE` update operation against a service endpoint.\n\nThe source graph must be specified with the `:graph` option and the destination graph with the\n`:to` option either as a string, `RDF.IRI`, vocabulary namespace term for the graph name or\n`:default` for the default graph.\n\n    SPARQL.Client.move(\"http://example.com/sparql\",\n      from: \"http://example.com/Graph1\", to: \"http://example.com/Graph2\")\n\n    SPARQL.Client.move(\"http://example.com/sparql\",\n      from: :default, to: EX.Graph)\n\n\nThe update operation can be run in `SILENT` mode by setting the `:silent` option to `true`.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#move/2"},{"type":"function","title":"SPARQL.Client.move/3","doc":"Executes a SPARQL `MOVE` update operation against a service endpoint.\n\nThis version only allows execution of `MOVE` updates given as string in raw-mode (see the\n[module documentation](`SPARQL.Client`) for more information on the raw-mode).\n\n    \"MOVE GRAPH   TO GRAPH  \"\n    |> SPARQL.Client.move(\"http://example.com/sparql\", raw_mode: true)\n\nSee `move/2` for how to execute a `MOVE` update with an automatically built update string.\n\nSee documentation of the generic `update/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#move/3"},{"type":"function","title":"SPARQL.Client.query/3","doc":"Executes any form of a SPARQL query operation against a service endpoint.\n\nThe query can either be given as string or as an already parsed `SPARQL.Query`.\n\n    \"SELECT * WHERE { ?s ?p ?o }\"\n    |> SPARQL.Client.query(query, \"http://dbpedia.org/sparql\")\n\n    with %SPARQL.Query{} = query <- SPARQL.Query.new(\"SELECT * WHERE { ?s ?p ?o }\") do\n      SPARQL.Client.query(query, \"http://dbpedia.org/sparql\")\n    end\n\nFor the execution of queries in raw-mode see the [module documentation](`SPARQL.Client`)\n\nThe result is in the success case returned in a `:ok` tuple or in error cases in an `:error`\ntuple with an error message or in case of a non-200 response by the SPARQL service with a\n`SPARQL.Client.HTTPError`.\n\nThe type of the result returned depends on the query form:\n\n- `SELECT` queries will return a `SPARQL.Query.Result` struct\n- `ASK` queries will return a `SPARQL.Query.Result` struct with the boolean\n  result in the `results` field\n- `CONSTRUCT` and `DESCRIBE` queries will return an RDF data structure","ref":"SPARQL.Client.html#query/3"},{"type":"function","title":"Specifying the request method - SPARQL.Client.query/3","doc":"The SPARQL 1.1 protocol spec defines [three methods](https://www.w3.org/TR/sparql11-protocol/#query-operation)\nto perform a SPARQL query operation via HTTP, which can be specified via the\n`:request_method` and `:protocol_version` options:\n\n1. query via GET: by setting the options as `request_method: :get` and `protocol_version: \"1.1\"`\n2. query via URL-encoded POST: by setting the options as `request_method: :post` and `protocol_version: \"1.0\"`\n3. query via POST directly: by setting the options as `request_method: :post` and `protocol_version: \"1.1\"`\n\nIn order to work with SPARQL 1.0 services out-of-the-box the second method,\nquery via URL-encoded POST, is the default.\n\nTo perform previous query via GET, you would have to call it like this:\n\n    SPARQL.Client.query(query, \"http://dbpedia.org/sparql\",\n      request_method: :get, protocol_version: \"1.1\")","ref":"SPARQL.Client.html#query/3-specifying-the-request-method"},{"type":"function","title":"Specifying the response format - SPARQL.Client.query/3","doc":"The `SPARQL.Client` can handle all the specified result formats for SPARQL\ntuple results (JSON, XML, CSV and TSV) and for `CONSTRUCT` and `DESCRIBE` queries\nall RDF serialization formats supported by [RDF.ex](https://github.com/rdf-elixir/rdf-ex)\ncan be handled.\n\nIf no custom `Accept` header is specified, all accepted formats for the resp.\nquery form will be set automatically, with\n\n- JSON being the preferred format for `SELECT` and `ASK` queries\n- Turtle being the preferred format for `CONSTRUCT` and `DESCRIBE` queries\n\nAlthough the returned result is mostly independent of the actually returned\nresponse format from the service, you might want to set it manually with the\n`:result_format` and the name of the format\n\n    SPARQL.Client.query(query, \"http://some.company.org/private/sparql\",\n      result_format: :xml)\n\nThese are the names of the supported formats:\n\n- tuple result formats: `:json, :xml, :csv, :tsv`\n- RDF result formats: `:turtle, :ntriples, :nquads, :jsonld`\n\nWhen a `:result_format` is specified the `Accept` header is set to the corresponding\nmedia type. You might however still want to overwrite the `Accept` header, for\nexample when a SPARQL service uses a non-standard media type for a format.\nNote that, when providing a custom non-standard `Accept` header the `result_format`\noption is mandatory.","ref":"SPARQL.Client.html#query/3-specifying-the-response-format"},{"type":"function","title":"Specifying an RDF Dataset - SPARQL.Client.query/3","doc":"The RDF dataset to be queried can be specified [as described in the spec](https://www.w3.org/TR/sparql11-protocol/#dataset)\nvia the `:default_graph` and `:named_graph` options and either a single graph\nname or lists of graphs.\n\n    SPARQL.Client.query(query, \"http://some.company.org/private/sparql\",\n      default_graph: \"http://www.example/sparql/\",\n      named_graph: [\n        \"http://www.other.example/sparql/\",\n        \"http://www.another.example/sparql/\"\n      ])\n\nSimilarly, the `:using_graph` and `:using_named_graph` can be used to\nspecify the dataset on update operation [as described in the spec](https://www.w3.org/TR/sparql11-protocol/#update-dataset).\n\n    SPARQL.Client.update(update, \"http://some.company.org/private/sparql\",\n      using_graph: \"http://www.example/sparql/\",\n      using_named_graph: [\n        \"http://www.other.example/sparql/\",\n        \"http://www.another.example/sparql/\"\n      ])","ref":"SPARQL.Client.html#query/3-specifying-an-rdf-dataset"},{"type":"function","title":"SPARQL.Client.select/3","doc":"Executes a SPARQL `SELECT` query operation against a service endpoint.\n\nSee documentation of the generic `query/3` function and the [module documentation](`SPARQL.Client`) for the available options.","ref":"SPARQL.Client.html#select/3"},{"type":"function","title":"SPARQL.Client.update/3","doc":"Executes any form of a SPARQL update operation against a service endpoint.\n\nIn case of this generic function, updates can be given only as string and executed in raw-mode\n(see the [module documentation](`SPARQL.Client`) for a description of the raw-mode)\n\n    \"\"\"\n    PREFIX dc:   \n    PREFIX xsd:  \n\n    INSERT\n    { GRAPH   { ?book ?p ?v } }\n    WHERE\n    { GRAPH   \n         { ?book dc:date ?date .\n           FILTER ( ?date > \"1970-01-01T00:00:00-02:00\"^^xsd:dateTime )\n           ?book ?p ?v\n    } }\n    \"\"\"\n    |> SPARQL.Client.update(\"http://example.com/sparql\", raw_mode: true)\n\n\nThe result for all updates is either `:ok` or an `:error` tuple in error cases with an error\nmessage or in case of a non-2XX response by the SPARQL service with a `SPARQL.Client.HTTPError`.","ref":"SPARQL.Client.html#update/3"},{"type":"function","title":"Specifying the request method - SPARQL.Client.update/3","doc":"The SPARQL 1.1 protocol spec defines [two methods](https://www.w3.org/TR/sparql11-protocol/#update-operation)\nto perform a SPARQL update operation via HTTP, which can be specified via the\n`request_method` option:\n\n1. Update via URL-encoded POST: by setting the options `request_method: :url_encoded`\n2. Update via POST directly: by setting the options `request_method: :direct` (default)","ref":"SPARQL.Client.html#update/3-specifying-the-request-method"},{"type":"module","title":"SPARQL.Client.Request","doc":"A struct representing a HTTP request of a SPARQL protocol operation.\n\nFor now, you won't have to deal with this struct that much.\nYou'll encounter it only as a member of a `SPARQL.Client.HTTPError` or when writing a custom\nconfig function for the HTTP headers (see documentation of the configuration options for `SPARQL.Client`).","ref":"SPARQL.Client.Request.html"},{"type":"type","title":"SPARQL.Client.Request.http_method/0","doc":"","ref":"SPARQL.Client.Request.html#t:http_method/0"},{"type":"type","title":"SPARQL.Client.Request.protocol_version/0","doc":"","ref":"SPARQL.Client.Request.html#t:protocol_version/0"},{"type":"type","title":"SPARQL.Client.Request.t/0","doc":"","ref":"SPARQL.Client.Request.html#t:t/0"},{"type":"exception","title":"SPARQL.Client.HTTPError","doc":"Exception returned when a HTTP request of a SPARQL protocol operation fails with a non-2XX status.\n\nThe `SPARQL.Client.Request` is included in the exception struct in the `:request` field.","ref":"SPARQL.Client.HTTPError.html"},{"type":"function","title":"SPARQL.Client.HTTPError.message/1","doc":"","ref":"SPARQL.Client.HTTPError.html#message/1"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nThis project adheres to [Semantic Versioning](http://semver.org/) and\n[Keep a CHANGELOG](http://keepachangelog.com).","ref":"changelog.html"},{"type":"extras","title":"v0.5.0 - 2024-08-07 - Change Log","doc":"This version upgrades to RDF.ex v2.0.\n\nElixir versions < 1.13 and OTP version < 23 are no longer supported","ref":"changelog.html#v0-5-0-2024-08-07"},{"type":"extras","title":"Added - Change Log","doc":"- support for dataset parameters `:using_graph` and `:using_named_graph`\n  on update operations\n- `:prefixes` option used by `SPARQL.Client.insert_data/3` and \n  `SPARQL.Client.delete_data/3` to specify custom prefixes to be used\n  when rendering the update","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- graph names on dataset parameters can be provided as RDF namespace terms","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- `SPARQL.Client.insert_data/3` and `SPARQL.Client.delete_data/3` with \n  `RDF.Dataset`s where the graphs had different prefixes associated,\n  resulted in invalid queries since not all prefixes were included in \n  the update prologue\n\n\n[Compare v0.4.2...v0.5.0](https://github.com/rdf-elixir/sparql_client/compare/v0.4.2...v0.5.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.4.2 - 2023-04-24 - Change Log","doc":"","ref":"changelog.html#v0-4-2-2023-04-24"},{"type":"extras","title":"Added - Change Log","doc":"- support for nimble_options 1.0","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change Log","doc":"- The `:update_request_method` was not correctly fetched from the application config.\n\n\n[Compare v0.4.1...v0.4.2](https://github.com/rdf-elixir/sparql_client/compare/v0.4.1...v0.4.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.4.1 - 2022-11-03 - Change Log","doc":"This version is just upgraded to RDF.ex 1.0.\n\nElixir versions < 1.11 are no longer supported\n\n\n[Compare v0.4.0...v0.4.1](https://github.com/rdf-elixir/sparql_client/compare/v0.4.0...v0.4.1)","ref":"changelog.html#v0-4-1-2022-11-03"},{"type":"extras","title":"v0.4.0 - 2022-03-22 - Change Log","doc":"With the latest SPARQL.ex version 0.3.7, RDF-star and SPARQL-star results can be handled now.\n\nElixir versions < 1.10 are no longer supported","ref":"changelog.html#v0-4-0-2022-03-22"},{"type":"extras","title":"Added - Change Log","doc":"- general `:logger` option on all `SPARQL.Client` functions\n  (instrumenting the `Tesla.Middleware.Logger`)","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- In consistency with the change in RDF.ex 0.10 to no longer support automatic \n  merges of `RDF.Dataset`s, the `:merge_graphs` option is no longer supported \n  on the `SPARQL.Client.insert_data/3` and `SPARQL.Client.delete_data/3` functions.\n\n\n[Compare v0.3.1...v0.4.0](https://github.com/rdf-elixir/sparql_client/compare/v0.3.1...v0.4.0)","ref":"changelog.html#changed"},{"type":"extras","title":"v0.3.1 - 2020-11-27 - Change Log","doc":"","ref":"changelog.html#v0-3-1-2020-11-27"},{"type":"extras","title":"Added - Change Log","doc":"- support for RDF-XML for graph results \n\n[Compare v0.3.0...v0.3.1](https://github.com/rdf-elixir/sparql_client/compare/v0.3.0...v0.3.1)","ref":"changelog.html#added"},{"type":"extras","title":"v0.3.0 - 2020-09-21 - Change Log","doc":"Elixir versions < 1.9 are no longer supported","ref":"changelog.html#v0-3-0-2020-09-21"},{"type":"extras","title":"Added - Change Log","doc":"- raw-mode with the `:raw_mode` option, which allows disabling of the processing of query strings, \n  passing them through as-is to the SPARQL endpoint\n- support for `INSERT DATA` and `DELETE DATA` updates with `SPARQL.Client.insert_data/3` and \n  `SPARQL.Client.delete_data/3` which are able to handle all types RDF.ex datastructures \n  (`RDF.Description`, `RDF.Graph`, `RDF.Dataset`) directly \n- support for `LOAD` updates with `SPARQL.Client.load/2` \n- support for `CLEAR` updates with `SPARQL.Client.clear/2` \n- support for all graph management operations with \n  - `SPARQL.Client.create/2` \n  - `SPARQL.Client.drop/2` \n  - `SPARQL.Client.copy/2` \n  - `SPARQL.Client.move/2` \n  - `SPARQL.Client.add/2` \n- the defaults for several options can now be configured globally via the application  \n  environment; please refer to the `SPARQL.Client` documentation for more information","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change Log","doc":"- the default request method for queries when using SPARQL protocol version 1.1 is now `:get`\n- improved error handling","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- the default HTTP `Accept` header used when no `:result_form` was provided on \n  `SPARQL.Client.query/3` contained a typo\n\n\n[Compare v0.2.2...v0.3.0](https://github.com/rdf-elixir/sparql_client/compare/v0.2.2...v0.3.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.2.2 - 2019-05-22 - Change Log","doc":"","ref":"changelog.html#v0-2-2-2019-05-22"},{"type":"extras","title":"Added - Change Log","doc":"- the `request_opts` options to `SPARQL.Client.query/3` which will be passed as \n the `opts` option value to the `Tesla.request/2` function\n\n[Compare v0.2.1...v0.2.2](https://github.com/rdf-elixir/sparql_client/compare/v0.2.1...v0.2.2)","ref":"changelog.html#added"},{"type":"extras","title":"v0.2.1 - 2018-09-17 - Change Log","doc":"","ref":"changelog.html#v0-2-1-2018-09-17"},{"type":"extras","title":"Fixed - Change Log","doc":"- Update to SPARQL.ex 0.2.1 whose Hex package no longer contains Erlang output\n  files of Leex and Yecc, which caused issues using the SPARQL.ex Hex package on\n  OTP < 21 (because the package was released with OTP 21)\n\n[Compare v0.2.0...v0.2.1](https://github.com/rdf-elixir/sparql_client/compare/v0.2.0...v0.2.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.2.0 - 2018-09-17 - Change Log","doc":"","ref":"changelog.html#v0-2-0-2018-09-17"},{"type":"extras","title":"Changed - Change Log","doc":"- adapt to new query result representation in SPARQL.ex 0.2\n- Elixir versions < 1.6 are no longer supported (as a consequence of upgrading\n  to the latest versions of RDF.ex and SPARQL.ex)\n\n\n[Compare v0.1.1...v0.2.0](https://github.com/rdf-elixir/sparql_client/compare/v0.1.1...v0.2.0)","ref":"changelog.html#changed"},{"type":"extras","title":"v0.1.1 - 2018-08-21 - Change Log","doc":"- Upgrade to Tesla 1.1\n\n[Compare v0.1.0...v0.1.1](https://github.com/rdf-elixir/sparql_client/compare/v0.1.0...v0.1.1)","ref":"changelog.html#v0-1-1-2018-08-21"},{"type":"extras","title":"v0.1.0 - 2018-03-19 - Change Log","doc":"Initial release","ref":"changelog.html#v0-1-0-2018-03-19"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}